==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Pro zastavení záznamu klepněte na ikonu
v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Pořídit snímek obrazovky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zachytávání obrazovky</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ukládání se nezdařilo. Uložte ho do své domovské složky.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Pořizování snímku dokončeno</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Vyberte oblast</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Zaznamenávání obrazovky se spustí za %1 sekund</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ukládání souboru se záznamem obrazovky – čekejte prosím…</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zachytávání obrazovky</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Záznam dokončen</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Zaznamenávání obrazovky se spustí za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Sem zadejte text</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Spustit/Pořídit snímek obrazovky</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Opustit/Uložit</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Kreslení</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Upravení velikosti</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Rychlé spuštění</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Snímek okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Pořídit snímek s prodlevou</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Roztáhnout nahoru</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Roztáhnout dolů</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Roztáhnout doleva</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Roztáhnout doprava</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Ubrat výšku nahoře</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Ubrat výšku dole</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Ubrat šířku nalevo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Ubrat šířku napravo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Rozmazání</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Zvuk zapnut</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Zvuk systému</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Zvuk vypnut</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Ukázat stisknutí klávesy</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Skrýt stisknutí klávesy</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webová kamera zapnuta</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webová kamera vypnuta</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Ukázat klepnutí</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>Skrýt klepnutí</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>SN/S:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 snímků/s</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 snímků/s</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 snímků/s</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 snímků/s</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 snímků/s</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Uložit do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>Upravit v kreslení</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zobrazit ukazatel</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Nahrávky</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>V současnosti není zaznamenávání obrazovky podporováno</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Pro zastavení záznamu klepněte na ikonu
v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Pořídit snímek obrazovky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Zachytávání obrazovky</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ukládání se nezdařilo. Uložte ho do své domovské složky.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Pořizování snímku dokončeno</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Vyberte oblast</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ukládání souboru se záznamem obrazovky – čekejte prosím…</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Protože v průběhu byl vypnutý efekt pro okno, nahrávání bylo zastaveno</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Pořídit snímek obrazovky</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Záznam dokončen</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Uloženo do %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Pořídit záznam</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Zaznamenávání obrazovky se spustí za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Sem zadejte text</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Spustit/Pořídit snímek obrazovky</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Opustit/Uložit</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Kreslení</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Upravení velikosti</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Rychlé spuštění</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Snímek okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Pořídit snímek s prodlevou</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Roztáhnout nahoru</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Roztáhnout dolů</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Roztáhnout doleva</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Roztáhnout doprava</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Ubrat výšku nahoře</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Ubrat výšku dole</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Ubrat šířku nalevo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Ubrat šířku napravo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Stisknutí klávesy</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webová kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Spustit záznam</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Rozmazání</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Zvuk zapnut</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Zvuk systému</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Zvuk vypnut</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Ukázat stisknutí klávesy</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Skrýt stisknutí klávesy</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webová kamera zapnuta</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webová kamera vypnuta</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Ukázat klepnutí</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>SN/S:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 snímků/s</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 snímků/s</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 snímků/s</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 snímků/s</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 snímků/s</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Uložit do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schránka</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zobrazit ukazatel</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Upravte oblast nahrávání v %1*%2 a získejte tak lepší video efekt</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Nahrávky</translation>
    </message>
</context>
</TS>
